@@ -405,6 +405,22 @@ impl Kubectl {
             Ok(v0::Provider::Generic)
         }
     }
+
+    pub(crate) async fn store_cluster_token(
+        &self,
+        namespace: &str,
+        token: &str,
+    ) -> anyhow::Result<Secret> {
+        let token = json::json!({ "cluster-token": token });
+
+        self.set_secret(
+            namespace,
+            STATEHUB_CLUSTER_TOKEN_SECRET_TYPE,
+            STATEHUB_CLUSTER_TOKEN_SECRET_NAME,
+            token,
+        )
+        .await
+    }
 }
 
 pub(crate) async fn list_namespaces() -> anyhow::Result<impl IntoIterator<Item = Namespace>> {
@@ -419,21 +435,6 @@ pub(crate) async fn list_pods() -> anyhow::Result<impl IntoIterator<Item = Pod>>
     Kubectl::new()?.all_pods(KUBE_SYSTEM_NS).await
 }
 
-pub(crate) async fn store_cluster_token(namespace: &str, token: &str) -> anyhow::Result<Secret> {
-    let kubectl = Kubectl::new()?;
-
-    let token = json::json!({ "cluster-token": token });
-
-    kubectl
-        .set_secret(
-            namespace,
-            STATEHUB_CLUSTER_TOKEN_SECRET_TYPE,
-            STATEHUB_CLUSTER_TOKEN_SECRET_NAME,
-            token,
-        )
-        .await
-}
-
 pub(crate) fn extract_cluster_token(secret: &Secret) -> Option<Cow<'_, str>> {
     secret
         .data
