@@ -6,29 +6,26 @@
 use k8s_openapi::apiextensions_apiserver::pkg::apis::apiextensions::v1::CustomResourceDefinition;
 use kube::CustomResourceExt;
 use kube::{Resource, ResourceExt};
+use serde_yaml as yaml;
 use statehub_cluster_operator::{ClusterSpec, StatehubCluster};
 
 use super::*;
 
+const STATE_CRD_YAML: &str = include_str!("states.state.statehub.io.yaml");
+
 impl Kubectl {
     pub(super) async fn create_statehub_cluster_crd(
         &self,
     ) -> anyhow::Result<CustomResourceDefinition> {
-        let mut crd = StatehubCluster::crd();
-        let name = crd.name();
-        let crds = self.api::<CustomResourceDefinition>().await?;
-        if let Ok(existing) = crds.get(&name).await {
-            crd.meta_mut().resource_version = existing.resource_version();
-        }
+        let crd = StatehubCluster::crd();
+        self.create_crd_impl(crd).await
+    }
 
-        let pp = self.post_params();
-
-        let crd = if crd.resource_version().is_some() {
-            crds.replace(&name, &pp, &crd).await?
-        } else {
-            crds.create(&pp, &crd).await?
-        };
-        Ok(crd)
+    pub(super) async fn create_statehub_state_crd(
+        &self,
+    ) -> anyhow::Result<CustomResourceDefinition> {
+        let crd = yaml::from_str::<CustomResourceDefinition>(STATE_CRD_YAML)?;
+        self.create_crd_impl(crd).await
     }
 
     pub(super) async fn create_statehub_cluster(
@@ -54,9 +51,8 @@ impl Kubectl {
         Ok(cluster)
     }
 
-    pub(super) async fn delete_statehub_cluster(&self) -> anyhow::Result<()> {
+    pub(super) async fn delete_statehub_cluster(&self, name: &str) -> anyhow::Result<()> {
         let clusters = self.api::<StatehubCluster>().await?;
-        let name = self.cluster_name();
         let dp = self.delete_params();
         clusters.delete(name, &dp).await?;
         Ok(())
@@ -71,6 +67,12 @@ impl Kubectl {
         Ok(())
     }
 
+    pub(super) async fn delete_statehub_state_crd(&self) -> anyhow::Result<()> {
+        let crd = yaml::from_str::<CustomResourceDefinition>(STATE_CRD_YAML)?;
+        let name = crd.name();
+        self.delete_crd_impl(&name).await
+    }
+
     pub(super) async fn check_statehub_cluster_crd(&self) -> anyhow::Result<String> {
         let name = StatehubCluster::crd().name();
         let crds = self.api::<CustomResourceDefinition>().await?;
@@ -88,4 +90,31 @@ impl Kubectl {
             cluster_name
         ))
     }
+
+    async fn create_crd_impl(
+        &self,
+        mut crd: CustomResourceDefinition,
+    ) -> anyhow::Result<CustomResourceDefinition> {
+        let name = crd.name();
+        let crds = self.api::<CustomResourceDefinition>().await?;
+        if let Ok(existing) = crds.get(&name).await {
+            crd.meta_mut().resource_version = existing.resource_version();
+        }
+
+        let pp = self.post_params();
+
+        let crd = if crd.resource_version().is_some() {
+            crds.replace(&name, &pp, &crd).await?
+        } else {
+            crds.create(&pp, &crd).await?
+        };
+        Ok(crd)
+    }
+
+    async fn delete_crd_impl(&self, name: &str) -> anyhow::Result<()> {
+        let crds = self.api::<CustomResourceDefinition>().await?;
+        let dp = self.delete_params();
+        crds.delete(name, &dp).await?;
+        Ok(())
+    }
 }
