@@ -427,6 +427,8 @@ enum Command {
         namespace: String,
         #[structopt(help = "Cluster token")]
         token: String,
+        #[structopt(help = "Kubeconfig context to use", long, short, visible_alias = "ctx")]
+        context: Option<String>,
     },
 
     #[structopt(
@@ -734,9 +736,11 @@ impl Cli {
 
                 statehub.uninstall_statehub(kubectls, force).await
             }
-            Command::SaveClusterToken { namespace, token } => {
-                statehub.save_cluster_token(namespace, token).await
-            }
+            Command::SaveClusterToken {
+                namespace,
+                token,
+                context,
+            } => statehub.save_cluster_token(namespace, token, context).await,
             Command::SetupConfigmap {
                 namespace,
                 cluster,
@@ -1186,8 +1190,15 @@ impl StateHub {
         Ok(())
     }
 
-    async fn save_cluster_token(&self, namespace: String, token: String) -> anyhow::Result<()> {
-        let secret = k8s::store_cluster_token(&namespace, &token).await?;
+    async fn save_cluster_token(
+        &self,
+        namespace: String,
+        token: String,
+        context: Option<String>,
+    ) -> anyhow::Result<()> {
+        let secret = k8s::Kubectl::with_context_or_current(context.as_deref())?
+            .store_cluster_token(&namespace, &token)
+            .await?;
         if let Some(token) = k8s::extract_cluster_token(&secret) {
             log::debug!("Token: {}", token);
         }
